#!/bin/bash -x
#
# Script consists of Part 1 of the FDR job 
#  - Prefill
#  - Save "Before FDR" logs
#  - Metricss
#  - Repeatability1/2
#  - Persistence1
#  - SPC2 Pers-Write
#
#


#
# Configure Variable
#
if [ $# -ne 2 ]
then
	IOPS=560000
else
	IOPS=$1
fi

PERSIOPS=$(( $IOPS / 4 ))
INITIOPS=5000

HOME=/home/dx600s4spc1v3/fdr;export HOME           # Absolute path of Home Template 
ROOT=/home/dx600s4spc1v3/fdrwork;export ROOT       # Absolute path of Work Directories
SCRIPTS=/home/dx600s4spc1v3/fdr/07_Execution;export SCRIPTS	# main script directory
TUNING=/home/dx600s4spc1v3/fdr/06_Tunables;export TUNING

# benchmark and misc commands
GETHOSTINFO="./getHostInfo.sh"
EXPORTLOG=exportLog.exp;export EXPORTLOG
EXPORTCFG=/home/dx600s4spc1v3/fdr/04_Repository/cliS3n.exp;export EXPORTCFG


# create tmp directory for dx600s4spc1v3 if it does not exist 
SPCTMP=/tmp/dx600s4spc1v3;export SPCTMP
if [ ! -d ${SPCTMP} ]; then      
	mkdir ${SPCTMP}
fi

#
# Create confID
#
confID=DX600S4_20180222;export confID

# obtain jobID based on the timestamp
# jobID uniquely identifies the benchmark run
jobID=JX`date +%y%m%d%H%M%S`;export jobID
WORKDIR=${ROOT}/${jobID};export WORKDIR # WORK Directory
#
mkdir $WORKDIR
for h in rx14 rx15 rx16 
do
ssh root@$h  "cd ${ROOT};mkdir ${jobID}"
done
#
# save Variables Part 2 use
#
echo $HOME > ${SPCTMP}/HOME
echo $ROOT > ${SPCTMP}/ROOT
echo $SCRIPTS > ${SPCTMP}/SCRIPTS
echo $confID > ${SPCTMP}/lastconfID
echo $jobID > ${SPCTMP}/lastjobID
echo $WORKDIR > ${SPCTMP}/WORKDIR
echo $EXPORTLOG > ${SPCTMP}/EXPORTLOG
echo $EXPORTCFG > ${SPCTMP}/EXPORTCFG
echo $PERSIOPS > ${SPCTMP}/PERSIOPS
echo $TUNING > ${SPCTMP}/TUNING
#
# setup the unique execution context(directory) for SPC1 job
#
# For Master host
# Copy the subdirectories to the new context 
cd $WORKDIR 
cp -r -p $HOME/*  .
echo -e DX600S4 "\n"  start time `date` "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo -e  confID=$confID "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo -e  jobID=$jobID "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo "Starting DX600S4 FDR Job=${jobID}" | tee -a ${SPCTMP}/${jobID}_message.txt
#
#setuplinux Tuning in all hosts
#
$TUNING/setupLinux.sh
for h in rx14 rx15 rx16 
do
ssh root@$h  "cd ${HOME}/06_Tunables;./setupLinux.sh"
done
#
# Collect Server/HBA Information 
#
echo "Starting  Server/HBA Information  Collection Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
cd ${WORKDIR}
cd 10_Reference_Info 
./getHostInfo.sh fdr_RX2540M4_${jobID}-rx13
# get Host Information from remote host rx2
for h in rx14 rx15 rx16 
do
  ssh root@${h} "cd ${WORKDIR};${HOME}/10_Reference_Info/getHostInfo.sh fdr_RX2540M4_${jobID}-${h}"
  scp root@${h}:${WORKDIR}/*fdr_RX2540M4_${jobID}-${h}*  .
done
echo "Completed  Server/HBA Information  Collection Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt

#
# Collect Log
#
${GETALLHOSTINFO}
cd ..
echo "Starting  DX600S4 BeforeF log save Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
# Save Before F log
${SCRIPTS}/${EXPORTLOG} ${jobID} BeforeF
${EXPORTCFG} ssh dx600s4 root 04_Repository/${jobID}_BeforeF.log
echo "Completed DX600S4 BeforeF log save Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt

# Start Sequence of SPC1 benchmark jobs
#
cd ${WORKDIR}/09_Results
cp ${SCRIPTS}/SPC1.${confID}.asu . 
sed "s/%%jobID%%/${jobID}/" < ${SCRIPTS}/SPC1.${confID}.hst >  SPC1.${confID}.hst
# create outuput directories in master and slave servers
mkdir ${WORKDIR}/outputrx13
for h in rx14 rx15 rx16 
do
  ssh root@${h} "cd ${WORKDIR};mkdir output${h}"
done

spc1 -master SPC1.${confID}.hst -run SPC1_INIT -iops ${INITIOPS} -storage SPC1.${confID}.asu 
spc1 -run SPC1_VERIFY -iops 100 -storage SPC1.${confID}.asu
spc1 -master SPC1.${confID}.hst -run SPC1_METRICS -iops ${IOPS} -storage SPC1.${confID}.asu
spc1 -run SPC1_VERIFY -iops 100 -storage SPC1.${confID}.asu
spc1 -master SPC1.${confID}.hst -run SPC1_PERSIST_1  -iops ${PERSIOPS} -storage SPC1.${confID}.asu

#
# Perform Power cycle
#
echo "Array is Ready for manual Power cycle Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
